SubsecondDigits

Enum SubsecondDigits 

#[non_exhaustive]
pub enum SubsecondDigits { One, Two, Three, Four, Five, Six, Seven, Eight, Nine, OneOrMore, }
Available on crate features formatting or parsing only.
The number of digits present in a subsecond representation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


One

Exactly one digit.



Two

Exactly two digits.



Three

Exactly three digits.



Four

Exactly four digits.



Five

Exactly five digits.



Six

Exactly six digits.



Seven

Exactly seven digits.



Eight

Exactly eight digits.



Nine

Exactly nine digits.



OneOrMore

Any number of digits (up to nine) that is at least one. When formatting, the minimum digits necessary will be used.

Implementations