#[non_exhaustive]pub enum YearRange {
Standard,
Extended,
}used only in the deprecated Year component
formatting or parsing only.Expand description
The range of years that are supported.
This modifier has no effect when the year repr is LastTwo.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Standard
used only in the deprecated Year component
Years between -9999 and 9999 are supported.
Extended
used only in the deprecated Year component
Years between -999_999 and 999_999 are supported, with the sign being required if the year contains more than four digits.
If the large-dates feature is not enabled, this variant is equivalent to Standard.
Implementations