impl_const_default

Macro impl_const_default 

macro_rules! impl_const_default {
    ($($(
        #[doc = $doc:expr])*
        $(#[cfg($($cfg:tt)+)])?
        $(#[expect($($expected:tt)+)])?
        $(@$pub:ident)? $type:ty => $default:expr;
    )*) => { ... };
}
Available on crate features formatting or parsing only.
Implement Default for the given type. This also generates an inherent implementation of a default method that is const fn, permitting the default value to be used in const contexts.