Hour

Struct Hour 

#[non_exhaustive]
pub struct Hour { pub padding: Padding, pub is_12_hour_clock: bool, }
๐Ÿ‘ŽDeprecated since 0.3.48: use Hour12 or Hour24 instead
Available on crate features formatting or parsing only.
Hour of the day.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
padding: Padding
๐Ÿ‘ŽDeprecated since 0.3.48: use Hour12 or Hour24 instead

The padding to obtain the minimum width.

is_12_hour_clock: bool
๐Ÿ‘ŽDeprecated since 0.3.48: use Hour12 or Hour24 instead

Is the hour displayed using a 12 or 24-hour clock?

Implementations

Source

impl Hour

pub const fn default() -> Self

Creates a modifier that indicates the value is padded with zeroes and has the 24-hour representation.

This function exists since Default::default() cannot be used in a const context. It may be removed once that becomes possible. As the Default trait is in the prelude, removing this function in the future will not cause any resolution failures for the overwhelming majority of users; only users who use #![no_implicit_prelude] will be affected. As such it will not be considered a breaking change.

Source

impl Hour

pub const fn with_padding(self, padding: Padding) -> Self

Set the padding type.

pub const fn with_is_12_hour_clock(self, is_12_hour_clock: bool) -> Self

Set whether the hour uses a 12-hour clock.