Hour12

Struct Hour12 

pub struct Hour12 {
    pub(crate) padding: Padding,
}
Available on crate features formatting or parsing only.
Hour of the day using a 12-hour clock.

Fields

padding: Padding

The padding to obtain the minimum width.

Implementations

Source

impl Hour12

pub const fn default() -> Self

This function exists since Default::default() cannot be used in a const context. It may be removed once that becomes possible. As the Default trait is in the prelude, removing this function in the future will not cause any resolution failures for the overwhelming majority of users; only users who use #![no_implicit_prelude] will be affected. As such it will not be considered a breaking change.

Source

impl Hour12

pub const fn with_padding(self, padding: Padding) -> Self

Set the padding type.