Month

Struct Month 

#[non_exhaustive]
pub struct Month { pub padding: Padding, pub repr: MonthRepr, pub case_sensitive: bool, }
๐Ÿ‘ŽDeprecated since 0.3.48: use MonthShort, MonthLong, or MonthNumeric instead
Available on crate features formatting or parsing only.
Month of the year.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
padding: Padding
๐Ÿ‘ŽDeprecated since 0.3.48: use MonthShort, MonthLong, or MonthNumeric instead

The padding to obtain the minimum width.

repr: MonthRepr
๐Ÿ‘ŽDeprecated since 0.3.48: use MonthShort, MonthLong, or MonthNumeric instead

What form of representation should be used?

case_sensitive: bool
๐Ÿ‘ŽDeprecated since 0.3.48: use MonthShort, MonthLong, or MonthNumeric instead

Is the value case sensitive when parsing?

Implementations

Source

impl Month

pub const fn default() -> Self

Creates an instance of this type that indicates the value uses the Numerical representation, is padded with zeroes, and is case-sensitive when parsing.

This function exists since Default::default() cannot be used in a const context. It may be removed once that becomes possible. As the Default trait is in the prelude, removing this function in the future will not cause any resolution failures for the overwhelming majority of users; only users who use #![no_implicit_prelude] will be affected. As such it will not be considered a breaking change.

Source

impl Month

pub const fn with_padding(self, padding: Padding) -> Self

Set the padding type.

pub const fn with_repr(self, repr: MonthRepr) -> Self

Set the manner in which the month is represented.

pub const fn with_case_sensitive(self, case_sensitive: bool) -> Self

Set whether the value is case sensitive when parsing.