pub struct MonthShort {
pub(crate) case_sensitive: bool,
}Available on crate features
formatting or parsing only.Expand description
Month of the year using the short form of the month name (e.g. “Jan”).
Fields
case_sensitive: boolIs the value case sensitive when parsing?
Implementations
Sourceimpl MonthShort
impl MonthShort
Sourcepub const fn default() -> Self
pub const fn default() -> Self
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl MonthShort
impl MonthShort
Sourcepub const fn with_case_sensitive(self, case_sensitive: bool) -> Self
pub const fn with_case_sensitive(self, case_sensitive: bool) -> Self
Set whether the value is case sensitive when parsing.