UnixTimestamp

Struct UnixTimestamp 

#[non_exhaustive]
pub struct UnixTimestamp { pub precision: UnixTimestampPrecision, pub sign_is_mandatory: bool, }
๐Ÿ‘ŽDeprecated since 0.3.48: use UnixTimestampSeconds, UnixTimestampMilliseconds, UnixTimestampMicroseconds, or UnixTimestampNanoseconds instead
Available on crate features formatting or parsing only.
A Unix timestamp.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
precision: UnixTimestampPrecision
๐Ÿ‘ŽDeprecated since 0.3.48: use UnixTimestampSeconds, UnixTimestampMilliseconds, UnixTimestampMicroseconds, or UnixTimestampNanoseconds instead

The precision of the timestamp.

sign_is_mandatory: bool
๐Ÿ‘ŽDeprecated since 0.3.48: use UnixTimestampSeconds, UnixTimestampMilliseconds, UnixTimestampMicroseconds, or UnixTimestampNanoseconds instead

Whether the + sign must be present for a non-negative timestamp.

Implementations

Source

impl UnixTimestamp

pub const fn default() -> Self

Creates a modifier that indicates the value represents the number of seconds since the Unix epoch. The sign is not mandatory.

This function exists since Default::default() cannot be used in a const context. It may be removed once that becomes possible. As the Default trait is in the prelude, removing this function in the future will not cause any resolution failures for the overwhelming majority of users; only users who use #![no_implicit_prelude] will be affected. As such it will not be considered a breaking change.

Source

impl UnixTimestamp

pub const fn with_precision(self, precision: UnixTimestampPrecision) -> Self

Set the precision of the timestamp.

pub const fn with_sign_is_mandatory(self, sign_is_mandatory: bool) -> Self

Set whether the + sign is mandatory for non-negative timestamps.