pub struct UnixTimestampSecond {
pub(crate) sign_is_mandatory: bool,
}Available on crate features
formatting or parsing only.Expand description
A Unix timestamp in seconds.
Fields
sign_is_mandatory: boolWhether the + sign must be present for a non-negative timestamp.
Implementations
Sourceimpl UnixTimestampSecond
impl UnixTimestampSecond
Sourcepub const fn default() -> Self
pub const fn default() -> Self
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl UnixTimestampSecond
impl UnixTimestampSecond
Sourcepub const fn with_sign_is_mandatory(self, sign_is_mandatory: bool) -> Self
pub const fn with_sign_is_mandatory(self, sign_is_mandatory: bool) -> Self
Set whether the + sign is mandatory for non-negative timestamps.