Weekday

Struct Weekday 

#[non_exhaustive]
pub struct Weekday { pub repr: WeekdayRepr, pub one_indexed: bool, pub case_sensitive: bool, }
๐Ÿ‘ŽDeprecated since 0.3.48: use WeekdayShort, WeekdayLong, WeekdaySunday, or WeekdayMonday instead
Available on crate features formatting or parsing only.
Day of the week.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
repr: WeekdayRepr
๐Ÿ‘ŽDeprecated since 0.3.48: use WeekdayShort, WeekdayLong, WeekdaySunday, or WeekdayMonday instead

What form of representation should be used?

one_indexed: bool
๐Ÿ‘ŽDeprecated since 0.3.48: use WeekdayShort, WeekdayLong, WeekdaySunday, or WeekdayMonday instead

When using a numerical representation, should it be zero or one-indexed?

case_sensitive: bool
๐Ÿ‘ŽDeprecated since 0.3.48: use WeekdayShort, WeekdayLong, WeekdaySunday, or WeekdayMonday instead

Is the value case sensitive when parsing?

Implementations

Source

impl Weekday

pub const fn default() -> Self

Creates a modifier that indicates the value uses the Long representation and is case-sensitive when parsing. If the representation is changed to a numerical one, the instance defaults to one-based indexing.

This function exists since Default::default() cannot be used in a const context. It may be removed once that becomes possible. As the Default trait is in the prelude, removing this function in the future will not cause any resolution failures for the overwhelming majority of users; only users who use #![no_implicit_prelude] will be affected. As such it will not be considered a breaking change.

Source

impl Weekday

pub const fn with_repr(self, repr: WeekdayRepr) -> Self

Set the manner in which the weekday is represented.

pub const fn with_one_indexed(self, one_indexed: bool) -> Self

Set whether the value is one-indexed when using a numerical representation.

pub const fn with_case_sensitive(self, case_sensitive: bool) -> Self

Set whether the value is case sensitive when parsing.