Year

Struct Year 

#[non_exhaustive]
pub struct Year { pub padding: Padding, pub repr: YearRepr, pub range: YearRange, pub iso_week_based: bool, pub sign_is_mandatory: bool, }
๐Ÿ‘ŽDeprecated since 0.3.48: use one of the various Year* components instead
Available on crate features formatting or parsing only.
Year of the date.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
padding: Padding
๐Ÿ‘ŽDeprecated since 0.3.48: use one of the various Year* components instead

The padding to obtain the minimum width.

repr: YearRepr
๐Ÿ‘ŽDeprecated since 0.3.48: use one of the various Year* components instead

What kind of representation should be used?

range: YearRange
๐Ÿ‘ŽDeprecated since 0.3.48: use one of the various Year* components instead

What range of years is supported?

iso_week_based: bool
๐Ÿ‘ŽDeprecated since 0.3.48: use one of the various Year* components instead

Whether the value is based on the ISO week number or the Gregorian calendar.

sign_is_mandatory: bool
๐Ÿ‘ŽDeprecated since 0.3.48: use one of the various Year* components instead

Whether the + sign is present when a non-negative year contains fewer digits than necessary.

Implementations

Source

impl Year

pub const fn default() -> Self

Creates a modifier that indicates the value uses the Full representation, is padded with zeroes, uses the Gregorian calendar as its base, and only includes the yearโ€™s sign if necessary.

This function exists since Default::default() cannot be used in a const context. It may be removed once that becomes possible. As the Default trait is in the prelude, removing this function in the future will not cause any resolution failures for the overwhelming majority of users; only users who use #![no_implicit_prelude] will be affected. As such it will not be considered a breaking change.

Source

impl Year

pub const fn with_padding(self, padding: Padding) -> Self

Set the padding type.

pub const fn with_repr(self, repr: YearRepr) -> Self

Set the manner in which the year is represented.

pub const fn with_range(self, range: YearRange) -> Self

Set the range of years that are supported.

pub const fn with_iso_week_based(self, iso_week_based: bool) -> Self

Set whether the year is based on the ISO week number.

pub const fn with_sign_is_mandatory(self, sign_is_mandatory: bool) -> Self

Set whether the + sign is mandatory for positive years with fewer than five digits.