WeekNumberRepr

Enum WeekNumberRepr 

#[non_exhaustive]
pub enum WeekNumberRepr { Iso, Sunday, Monday, }
๐Ÿ‘ŽDeprecated since 0.3.48: used only in the deprecated WeekNumber component
Available on crate features formatting or parsing only.
The representation used for the week number.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Iso

๐Ÿ‘ŽDeprecated since 0.3.48: used only in the deprecated WeekNumber component

Week 1 is the week that contains January 4.



Sunday

๐Ÿ‘ŽDeprecated since 0.3.48: used only in the deprecated WeekNumber component

Week 1 begins on the first Sunday of the calendar year.



Monday

๐Ÿ‘ŽDeprecated since 0.3.48: used only in the deprecated WeekNumber component

Week 1 begins on the first Monday of the calendar year.

Implementations