#[non_exhaustive]pub enum YearRange {
Standard,
Extended,
}๐Deprecated since 0.3.48: used only in the deprecated
Year componentAvailable on crate features
formatting or parsing only.Expand description
The range of years that are supported.
This modifier has no effect when the year repr is LastTwo.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Standard
๐Deprecated since 0.3.48: used only in the deprecated
Year componentYears between -9999 and 9999 are supported.
Extended
๐Deprecated since 0.3.48: used only in the deprecated
Year componentYears between -999_999 and 999_999 are supported, with the sign being required if the year contains more than four digits.
If the large-dates feature is not enabled, this variant is equivalent to Standard.
Implementations