pub struct IsoYearFullStandardRange {
pub(crate) padding: Padding,
pub(crate) sign_is_mandatory: bool,
}Available on crate features
formatting or parsing only.Expand description
Year of the date. All digits are included, the ISO week-numbering year is used, and the range of supported is ±9,999.
Fields
padding: PaddingThe padding to obtain the minimum width.
sign_is_mandatory: boolWhether the + sign is present when a non-negative year contains fewer digits than
necessary.
Implementations
Sourceimpl IsoYearFullStandardRange
impl IsoYearFullStandardRange
Sourcepub const fn default() -> Self
pub const fn default() -> Self
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl IsoYearFullStandardRange
impl IsoYearFullStandardRange
Sourcepub const fn with_padding(self, padding: Padding) -> Self
pub const fn with_padding(self, padding: Padding) -> Self
Set the padding type.
Sourcepub const fn with_sign_is_mandatory(self, sign_is_mandatory: bool) -> Self
pub const fn with_sign_is_mandatory(self, sign_is_mandatory: bool) -> Self
Set whether the + sign is present on non-negative years.