#[non_exhaustive]pub struct Month {
pub padding: Padding,
pub repr: MonthRepr,
pub case_sensitive: bool,
}MonthShort, MonthLong, or MonthNumeric insteadformatting or parsing only.Expand description
Month of the year.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.padding: PaddingMonthShort, MonthLong, or MonthNumeric insteadThe padding to obtain the minimum width.
repr: MonthReprMonthShort, MonthLong, or MonthNumeric insteadWhat form of representation should be used?
case_sensitive: boolMonthShort, MonthLong, or MonthNumeric insteadIs the value case sensitive when parsing?
Implementations
Sourceimpl Month
impl Month
Sourcepub const fn default() -> Self
pub const fn default() -> Self
Creates an instance of this type that indicates the value uses the
Numerical representation, is padded with zeroes,
and is case-sensitive when parsing.
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl Month
impl Month
Sourcepub const fn with_padding(self, padding: Padding) -> Self
pub const fn with_padding(self, padding: Padding) -> Self
Set the padding type.
Sourcepub const fn with_repr(self, repr: MonthRepr) -> Self
pub const fn with_repr(self, repr: MonthRepr) -> Self
Set the manner in which the month is represented.
Sourcepub const fn with_case_sensitive(self, case_sensitive: bool) -> Self
pub const fn with_case_sensitive(self, case_sensitive: bool) -> Self
Set whether the value is case sensitive when parsing.