pub struct WeekdayMonday {
pub(crate) one_indexed: bool,
}Available on crate features
formatting or parsing only.Expand description
Day of the week using a numerical representation with Monday as the first day of the week.
Fields
one_indexed: boolIs the value zero or one-indexed?
Implementations
Sourceimpl WeekdayMonday
impl WeekdayMonday
Sourcepub const fn default() -> Self
pub const fn default() -> Self
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl WeekdayMonday
impl WeekdayMonday
Sourcepub const fn with_one_indexed(self, one_indexed: bool) -> Self
pub const fn with_one_indexed(self, one_indexed: bool) -> Self
Set whether the value is one-indexed.